Contents
=========

Introduction
---------------
.. toctree::
   :maxdepth: 1

   intro
   install
   initialize
   config
   tutorial

The ``gt`` workflow management script
--------------------------------------------------

  .. toctree::
   :maxdepth: 1

   gcamtool
   setup
   gui

XML File Formats
------------------

  .. toctree::
   :maxdepth: 1

   xmlFiles
   conditional-xml

Application Programming Interface (API)
----------------------------------------

  .. toctree::
   :maxdepth: 1

   api

Monte Carlo Simulation support
---------------------------------

  .. toctree::
   :maxdepth: 1

   mcs/index

For PIC Users
-------------

  .. toctree::
   :maxdepth: 1

   pic
